inline void FBB::OFoldBuf::useBlanks()
{
    d_indentChar = ' ';
    d_indentWidth = 1;
}
